@@ -21,8 +21,8 @@ installed_mods = utils.installed_modules()
 for mod, installed in installed_mods.iteritems():
     
     # but don't add core urls (this file) again
-    if installed is True and mod is not 'djhcup_core':
+    if installed is True and mod not in ['djhcup_core']:
         prefix = mod.split('_')[-1]
         urlpatterns += patterns('',
                                 url(r'^%s/' % prefix, include('%s.urls' % mod)),
-                                )
\ No newline at end of file
+                                )
